@@ -11,6 +11,19 @@ from PySFML import sf
 
 import os
 
+class Sonido:
+
+    def __init__(self, buffer):
+        self.buffer = buffer
+        self.sonido = sf.Sound(buffer)
+        pass
+
+    def reproducir(self):
+        self.sonido.Play()
+    
+    def Play(self):
+        self.reproducir()
+
 def cargar(ruta):
     """Carga un sonido para reproducir, donde el argumento ``ruta`` indica cual es el archivo.
 
@@ -37,4 +50,4 @@ def cargar(ruta):
 
     buff = sf.SoundBuffer()
     buff.LoadFromFile(path)
-    return sf.Sound(buff)
+    return Sonido(buff)
